@@ -35,10 +35,7 @@
 
 DiscoverNotifier::DiscoverNotifier(QObject * parent)
     : QObject(parent)
-    , m_manager(new QNetworkConfigurationManager(this))
 {
-    configurationChanged();
-
     m_backends = BackendNotifierFactory().allBackends();
     foreach(BackendNotifierModule* module, m_backends) {
         connect(module, &BackendNotifierModule::foundUpdates, this, &DiscoverNotifier::updateStatusNotifier);
@@ -58,44 +55,37 @@ DiscoverNotifier::DiscoverNotifier(QObject * parent)
     m_timer.setInterval(1000);
     updateStatusNotifier();
 
-    connect(m_manager, &QNetworkConfigurationManager::onlineStateChanged, this, &DiscoverNotifier::stateChanged);
-
     //Only fetch updates after the system is comfortably booted
-    QTimer::singleShot(10000, this, &DiscoverNotifier::recheckSystemUpdateNeeded);
+    QTimer::singleShot(20000, this, &DiscoverNotifier::recheckSystemUpdateNeeded);
 }
 
 DiscoverNotifier::~DiscoverNotifier() = default;
 
-void DiscoverNotifier::configurationChanged()
-{
-    KConfig notifierConfig(QStringLiteral("plasma-discover-notifierrc"), KConfig::NoGlobals);
-
-    KConfigGroup notifyTypeGroup(&notifierConfig, "NotificationType");
-    m_verbose = notifyTypeGroup.readEntry("Verbose", false);
-}
-
 void DiscoverNotifier::showDiscover()
 {
     KRun::runCommand(QStringLiteral("plasma-discover"), nullptr);
+    if (m_updatesAvailableNotification) { m_updatesAvailableNotification->close(); }
 }
 
 void DiscoverNotifier::showDiscoverUpdates()
 {
     KRun::runCommand(QStringLiteral("plasma-discover --mode update"), nullptr);
+    if (m_updatesAvailableNotification) { m_updatesAvailableNotification->close(); }
 }
 
 void DiscoverNotifier::showUpdatesNotification()
 {
+    if (m_updatesAvailableNotification) { m_updatesAvailableNotification->close(); }
     if (state() != NormalUpdates && state() != SecurityUpdates) {
         //it's not very helpful to notify that everything is in order
         return;
     }
 
-    auto e = KNotification::event(QStringLiteral("Update"), message(), {}, iconName(), nullptr, KNotification::CloseOnTimeout, QStringLiteral("discoverabstractnotifier"));
+    m_updatesAvailableNotification = KNotification::event(QStringLiteral("Update"), message(), {}, iconName(), nullptr, KNotification::Persistent, QStringLiteral("discoverabstractnotifier"));
     const QString name = i18n("Update");
-    e->setDefaultAction(name);
-    e->setActions({name});
-    connect(e, QOverload<unsigned int>::of(&KNotification::activated), this, &DiscoverNotifier::showDiscoverUpdates);
+    m_updatesAvailableNotification->setDefaultAction(name);
+    m_updatesAvailableNotification->setActions({name});
+    connect(m_updatesAvailableNotification, QOverload<unsigned int>::of(&KNotification::activated), this, &DiscoverNotifier::showDiscoverUpdates);
 }
 
 void DiscoverNotifier::updateStatusNotifier()
@@ -120,7 +110,7 @@ DiscoverNotifier::State DiscoverNotifier::state() const
 {
     if (m_needsReboot)
         return RebootRequired;
-    else if (!m_manager->isOnline())
+    else if (m_manager && !m_manager->isOnline())
         return Offline;
     else if (m_hasSecurityUpdates)
         return SecurityUpdates;
@@ -166,6 +156,14 @@ QString DiscoverNotifier::message() const
 
 void DiscoverNotifier::recheckSystemUpdateNeeded()
 {
+    if (!m_manager) {
+        m_manager = new QNetworkConfigurationManager(this);
+        connect(m_manager, &QNetworkConfigurationManager::onlineStateChanged, this, &DiscoverNotifier::stateChanged);
+        if (!m_manager->isOnline()) {
+            emit stateChanged();
+        }
+    }
+
     foreach(BackendNotifierModule* module, m_backends)
         module->recheckSystemUpdateNeeded();
 }
